#include <d.h>
#include <hdfutil.h>

static hdf_attr ExtractAttrVals(Pix p);

// extract all the attributes attached for variable varname
vector <hdf_attr> GetAttrs(const DAS& das, const String& varname) {
    vector<hdf_attr> attrs;
    for (Pix p=das.first_var(); p; das.next_var(p))
	if (das.var(p).name() == varname)
	    break;
    if (p == 0)
	return 0;		//  could not find variable named varname

    AttrTable *at = das.get_table(p);
    hdf_attr attr;
    Pix p;
    for (p=das.first_var(); p; das.next_var(p)) {
	attr = ExtractAttrVals(p);
	attrs.push_back(attr);
    }
    return attrs;
}

// extract the attribute attrname attached for variable varname
hdf_attr GetAttr(const DAS& das, const String& varname, 
		 const String& attrname) {
    // locate variable in DAS, attribute in AttrTable
    Pix p;
    for (p=das.first_var(); p; das.next_var(p))
	if (das.var(p).name() == varname)
	    break;
    if (p == 0)
	return 0;		//  could not find variable named varname

    AttrTable *at = das.get_table(p);
    for (p=at->first_attr(); p; at->next_attr(p))
	if (at->get_name(p) == attrname)
	    break;
    if (p == 0)
	return 0;		// could not find attribute named attrname

    hdf_attr& attr = ExtractAttrVals(p); // extract attribute values

    return attr;
}    
	
	    
// extract the attributes for the attribute pointed to by p and store in
// an hdf_attr structure
static hdf_attr ExtractAttrVals(Pix p) {

    // extract attribute Strings from AttrTable
    vector<String> attrs;
    for (int i=0; i<at->get_attr_num(p); ++i)
	attrs.push_back(at->get_attr(p,i));

    // store attribute in hdf_attr
    hdf_attr a;
    a->name = dods2id(attrname);
    a->values.import(HDFTypeName(at->get_type(p)), attrs);

    return a;
}    
