//////////////////////////////////////////////////////////////////////////////
// Copyright (c) 1996, California Institute of Technology.  
// ALL RIGHTS RESERVED.   U.S. Government Sponsorship acknowledged. 
//
// Please read the full copyright notice in the file COPYRIGH 
// in this directory.
//
// Author: Todd Karakashian, NASA/Jet Propulsion Laboratory
//         Todd.K.Karakashian@jpl.nasa.gov
//
// $RCSfile: hdf_das.cc,v $ - server CGI to send the DAS
// 
// $Log: hdf_das.cc,v $
// Revision 1.8  1999/05/06 03:23:36  jimg
// Merged changes from no-gnu branch
//
// Revision 1.7.6.1  1999/05/06 00:27:24  jimg
// Jakes String --> string changes
//
// Revision 1.6  1998/04/03 18:34:27  jimg
// Fixes for vgroups and Sequences from Jake Hamby
//
// Revision 1.5  1997/12/30 23:50:54  jimg
// Changed from the old-style filter program to one based on the new DODSFilter
// class.
//
// Revision 1.4  1997/03/10 22:45:52  jimg
// Update for 2.12
//
// Revision 1.3  1996/09/24 22:34:09  todd
// Added copyright statement.
//
// Revision 1.2  1996/07/22  20:32:33  todd
// Changes for DODS DAP 2.06.
//
// Revision 1.1  1996/05/02  18:14:01  todd
// Initial revision
//
//////////////////////////////////////////////////////////////////////////////

#include <iostream>
#include <strstream.h>

#include "DAS.h"
#include "cgi_util.h"
#include "DODSFilter.h"
#include "hcerr.h"
#include "dhdferr.h"

extern void read_das(DAS& das, const string& cachedir, const string& filename);

int 
main(int argc, char *argv[])
{
    DAS das;
    DODSFilter df(argc, argv);

    if (!df.OK()) {
	df.print_usage();
	return 1;
    }

    if (df.version()) {
	df.send_version_info();
	return 0;
    }

    // Read the file attributes in memory and forward all the errors to
    // client program
#ifndef NO_EXCEPTIONS
    try {
#endif
      read_das(das, df.get_cache_dir(), df.get_dataset_name());
      
      if (!df.read_ancillary_das(das))
	return 1;
      
      if (!df.send_das(das))
	return 1;

#ifndef NO_EXCEPTIONS
    }
    catch (dhdferr &d) {
        ostrstream s;
	s << "hdf_dods: " << d << ends;
        ErrMsgT(s.str());
	Error e(unknown_error, d.errmsg());
	set_mime_text(cout, dods_error);
	e.print(cout);
	return 1;
    }
    catch (hcerr &h) {
        ostrstream s;
	s << "hdf_dods: " << h << ends;
        ErrMsgT(s.str());
	Error e(unknown_error, h.errmsg());
	set_mime_text(cout, dods_error);
	e.print(cout);
	return 1;
    }
    catch (...) {
        string s("hdf_dods: Unknown exception");
	ErrMsgT(s);
	Error e(unknown_error, s);
	set_mime_text(cout, dods_error);
	e.print(cout);
	return 1;
    }
#endif

    return 0;
}
